@@ -17,7 +17,7 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with damenltk; see the file COPYING.  If not, write to
+# along with damenltk; see the file LICENSE.  If not, write to
 # the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 # Boston, MA 02110-1301 USA,
 
@@ -31,7 +31,10 @@ from nltk.corpus import cmudict
 from nltk.corpus import twitter_samples
 from nltk.corpus import verbnet
 from nltk.corpus import wordnet
-
+from collections import Counter
+# fix for MacOS using nose
+import collections
+collections.Callable = collections.abc.Callable
 
 class TddInPythonExample(unittest.TestCase):
 
@@ -41,6 +44,12 @@ class TddInPythonExample(unittest.TestCase):
                           '1793-Washington.txt',
                           '1797-Adams.txt'], fileids[0:3])
 
+    def test_corpus_bag_of_words_returns_correct_result(self):
+        counts = Counter(reuters.words())
+        self.assertEqual([('.', 94687), (',', 72360), ('the', 58251),
+                          ('of', 35979), ('to', 34035)],
+                         counts.most_common(n=5))
+
     def test_corpus_sents_method_returns_correct_result(self):
         sents1 = [['[', 'Sense', 'and', 'Sensibility',
                    'by', 'Jane', 'Austen', '1811', ']'],
