@@ -17,7 +17,7 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with damenltk; see the file COPYING.  If not, write to
+# along with damenltk; see the file LICENSE.  If not, write to
 # the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 # Boston, MA 02110-1301 USA,
 
@@ -63,3 +63,10 @@ class TddInPythonExample(unittest.TestCase):
                'won', 'wouldn']
         self.assertEqual(st0[0], st1[0])
         self.assertEqual(st0[4], st1[4])
+
+    def test_stopwords_spanish_method_returns_correct_result(self):
+        st0 = stopwords.words('spanish')
+        self.assertEqual(st0[0], "de")
+        self.assertEqual(st0[-1], "tened")
+
+        
